==> jc-1.4.0.tar.gz: javax/print/event/PrintEvent.c <==
// public class javax.print.event.PrintEvent

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 4c95768fb6372ef3 javax_print_event_PrintEvent

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_IllegalArgumentException
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header java_lang_VMThrowable
// @dep_header javax_print_event_PrintEvent

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/IllegalArgumentException.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "java/lang/VMThrowable.h"
#include "javax/print/event/PrintEvent.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.Object)
//

static _jc_linenum _jc_javax_print_event_PrintEvent$linenum_table$_init$3fddd28dadb712ab[];

static const unsigned char _jc_javax_print_event_PrintEvent$param_ptypes$_init$3fddd28dadb712ab[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_print_event_PrintEvent$param_types$_init$3fddd28dadb712ab[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_javax_print_event_PrintEvent$method_info$_init$3fddd28dadb712ab = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/Object;)V",
	.class=			&_jc_javax_print_event_PrintEvent$type,
	.param_types=		&_jc_javax_print_event_PrintEvent$param_types$_init$3fddd28dadb712ab,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_print_event_PrintEvent$param_ptypes$_init$3fddd28dadb712ab,
	.signature_hash=	_JC_JLONG(0x3fddd28dadb712ab),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_print_event_PrintEvent$method$_init$3fddd28dadb712ab,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_print_event_PrintEvent$linenum_table$_init$3fddd28dadb712ab
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_print_event_PrintEvent, _init$3fddd28dadb712ab);

void
_jc_javax_print_event_PrintEvent$method$_init$3fddd28dadb712ab(_jc_env *const env, _jc_javax_print_event_PrintEvent$object *this, _jc_java_lang_Object$object *param0)
{
	struct _jc_javax_print_event_PrintEvent$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_IllegalArgumentException$object *r2;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_lang_VMThrowable$object *r5;

	r0 = this;
	r1 = param0;
	if (r1 != _JC_NULL)
		goto label0;
	r2 = _JC_NEW(env, java_lang_IllegalArgumentException);
	r3 = _JC_NULL;
	_JC_REF_FIELD(env, r2, java_lang_Throwable, cause) = r2;
	r5 = _JC_INVOKE_STATIC(env, java_lang_VMThrowable, fillInStackTrace$78894ac70fa4c0a5, 0, r2);
	_JC_REF_FIELD(env, r2, java_lang_Throwable, vmState) = r5;
	_JC_REF_FIELD(env, r2, java_lang_Throwable, stackTrace) = _JC_NULL;
	_JC_REF_FIELD(env, r2, java_lang_Throwable, detailMessage) = r3;
	_JC_THROW(env, r2);

label0:
	_JC_REF_FIELD(env, r0, java_util_EventObject, source) = r1;
	_JC_LINE_NUMBER(56);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String toString()
//

static _jc_linenum _jc_javax_print_event_PrintEvent$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_javax_print_event_PrintEvent$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_print_event_PrintEvent$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_javax_print_event_PrintEvent$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_print_event_PrintEvent$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_print_event_PrintEvent$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_print_event_PrintEvent$vtable, javax_print_event_PrintEvent.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_print_event_PrintEvent$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_print_event_PrintEvent, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_javax_print_event_PrintEvent$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_javax_print_event_PrintEvent$object *this)
{
	jint i0;
	struct _jc_javax_print_event_PrintEvent$object *r0;
	struct _jc_java_lang_StringBuffer$object *r1;
	struct _jc_java_lang_Object$object *r2;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_lang_String$object *r5;
	_jc_char_array *r6;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(65);				// 0
	r1 = _JC_NEW(env, java_lang_StringBuffer);
	r5 = _JC_STRING(env, "PrintEvent on ");
	i0 = _JC_PRIM_FIELD(env, r5, java_lang_String, count);
	_JC_PRIM_FIELD(env, r1, java_lang_StringBuffer, count) = i0;
	i0 = _JC_PRIM_FIELD(env, r1, java_lang_StringBuffer, count);
	i0 = i0 + 16;
	r6 = _JC_NEW_PRIM_ARRAY(env, char, 1, i0);
	_JC_REF_FIELD(env, r1, java_lang_StringBuffer, value) = r6;
	i0 = _JC_PRIM_FIELD(env, r1, java_lang_StringBuffer, count);
	r6 = _JC_REF_FIELD(env, r1, java_lang_StringBuffer, value);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, getChars$c684dea7317ff063, 0, r5, 0, i0, r6, 0);
	r2 = _JC_INVOKE_VIRTUAL(env, java_util_EventObject, getSource$b11b93305f9d301e, r0);
	r3 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, toString$7ea43b33b80a3070, r2);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r3);
	r4 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r4, r1);
	return r4;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_print_event_PrintEvent$methods[] = {
	&_jc_javax_print_event_PrintEvent$method_info$_init$3fddd28dadb712ab,
	&_jc_javax_print_event_PrintEvent$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_print_event_PrintEvent$instanceof_hash_bucket_43[] = {
	&_jc_java_util_EventObject$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_print_event_PrintEvent$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_print_event_PrintEvent$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_print_event_PrintEvent$instanceof_hash_bucket_115[] = {
	&_jc_javax_print_event_PrintEvent$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_print_event_PrintEvent$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[43]=	_jc_javax_print_event_PrintEvent$instanceof_hash_bucket_43,
	[65]=	_jc_javax_print_event_PrintEvent$instanceof_hash_bucket_65,
	[113]=	_jc_javax_print_event_PrintEvent$instanceof_hash_bucket_113,
	[115]=	_jc_javax_print_event_PrintEvent$instanceof_hash_bucket_115
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_print_event_PrintEvent$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/IllegalArgumentException",	_JC_JLONG(0x680cf34d05feb5a1) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/RuntimeException",	_JC_JLONG(0x4f5534a987354d1d) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThrowable",	_JC_JLONG(0xc8d6a6ffc5c1acc1) },
	{ "java/util/EventObject",	_JC_JLONG(0xe4988e4c1a7050ab) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_print_event_PrintEvent$vtype _jc_javax_print_event_PrintEvent$type = {
    .type= {
	.name=			"javax/print/event/PrintEvent",
	.superclass=		&_jc_java_util_EventObject$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0x4c95768fb6372ef3),
		.source_file=		"PrintEvent.java",
		.instance_size=		sizeof(_jc_javax_print_event_PrintEvent$refs) + sizeof(_jc_javax_print_event_PrintEvent$object),
		.num_virtual_refs=	1,
		.num_methods=		sizeof(_jc_javax_print_event_PrintEvent$methods) / sizeof(*_jc_javax_print_event_PrintEvent$methods),
		.methods=		_jc_javax_print_event_PrintEvent$methods,
		.instanceof_hash_table=	_jc_javax_print_event_PrintEvent$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_print_event_PrintEvent$class_depends) / sizeof(*_jc_javax_print_event_PrintEvent$class_depends),
		.class_depends=		_jc_javax_print_event_PrintEvent$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_javax_print_event_PrintEvent$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_util_EventObject= {
	    .getSource$b11b93305f9d301e=
		&_jc_java_util_EventObject$method$getSource$b11b93305f9d301e,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_javax_print_event_PrintEvent$method$toString$7ea43b33b80a3070,
	},
	.javax_print_event_PrintEvent= {
	    .toString$7ea43b33b80a3070=
		&_jc_javax_print_event_PrintEvent$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/print/event/PrintEvent.c <==
// public class javax.print.event.PrintEvent

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c8d6a6ffc5c1acc1 java_lang_VMThrowable
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 4c95768fb6372ef3 javax_print_event_PrintEvent

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_IllegalArgumentException
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header java_lang_VMThrowable
// @dep_header javax_print_event_PrintEvent

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/IllegalArgumentException.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "java/lang/VMThrowable.h"
#include "javax/print/event/PrintEvent.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.Object)
//

static _jc_linenum _jc_javax_print_event_PrintEvent$linenum_table$_init$3fddd28dadb712ab[];

static const unsigned char _jc_javax_print_event_PrintEvent$param_ptypes$_init$3fddd28dadb712ab[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_print_event_PrintEvent$param_types$_init$3fddd28dadb712ab[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_javax_print_event_PrintEvent$method_info$_init$3fddd28dadb712ab = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/Object;)V",
	.class=			&_jc_javax_print_event_PrintEvent$type,
	.param_types=		&_jc_javax_print_event_PrintEvent$param_types$_init$3fddd28dadb712ab,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_print_event_PrintEvent$param_ptypes$_init$3fddd28dadb712ab,
	.signature_hash=	_JC_JLONG(0x3fddd28dadb712ab),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_print_event_PrintEvent$method$_init$3fddd28dadb712ab,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_print_event_PrintEvent$linenum_table$_init$3fddd28dadb712ab
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_print_event_PrintEvent, _init$3fddd28dadb712ab);

void _JC_JCNI_ATTR
_jc_javax_print_event_PrintEvent$method$_init$3fddd28dadb712ab(_jc_env *const env, _jc_javax_print_event_PrintEvent$object *this, _jc_java_lang_Object$object *param0)
{
	struct _jc_javax_print_event_PrintEvent$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_IllegalArgumentException$object *r2;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_lang_VMThrowable$object *r5;

	r0 = this;
	r1 = param0;
	if (r1 != _JC_NULL)
		goto label0;
	r2 = _JC_NEW(env, java_lang_IllegalArgumentException);
	r3 = _JC_NULL;
	_JC_REF_FIELD(env, r2, java_lang_Throwable, cause) = r2;
	r5 = _JC_INVOKE_STATIC(env, java_lang_VMThrowable, fillInStackTrace$78894ac70fa4c0a5, 0, r2);
	_JC_REF_FIELD(env, r2, java_lang_Throwable, vmState) = r5;
	_JC_REF_FIELD(env, r2, java_lang_Throwable, stackTrace) = _JC_NULL;
	_JC_REF_FIELD(env, r2, java_lang_Throwable, detailMessage) = r3;
	_JC_THROW(env, r2);

label0:
	_JC_REF_FIELD(env, r0, java_util_EventObject, source) = r1;
	_JC_LINE_NUMBER(56);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String toString()
//

static _jc_linenum _jc_javax_print_event_PrintEvent$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_javax_print_event_PrintEvent$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_print_event_PrintEvent$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_javax_print_event_PrintEvent$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_javax_print_event_PrintEvent$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_print_event_PrintEvent$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_print_event_PrintEvent$vtable, javax_print_event_PrintEvent.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_print_event_PrintEvent$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_print_event_PrintEvent, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_javax_print_event_PrintEvent$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_javax_print_event_PrintEvent$object *this)
{
	jint i0;
	struct _jc_javax_print_event_PrintEvent$object *r0;
	struct _jc_java_lang_StringBuffer$object *r1;
	struct _jc_java_lang_Object$object *r2;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_lang_String$object *r5;
	_jc_char_array *r6;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(65);				// 0
	r1 = _JC_NEW(env, java_lang_StringBuffer);
	r5 = _JC_STRING(env, "PrintEvent on ");
	i0 = _JC_PRIM_FIELD(env, r5, java_lang_String, count);
	_JC_PRIM_FIELD(env, r1, java_lang_StringBuffer, count) = i0;
	i0 = _JC_PRIM_FIELD(env, r1, java_lang_StringBuffer, count);
	i0 = i0 + 16;
	r6 = _JC_NEW_PRIM_ARRAY(env, char, 1, i0);
	_JC_REF_FIELD(env, r1, java_lang_StringBuffer, value) = r6;
	i0 = _JC_PRIM_FIELD(env, r1, java_lang_StringBuffer, count);
	r6 = _JC_REF_FIELD(env, r1, java_lang_StringBuffer, value);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, getChars$c684dea7317ff063, 0, r5, 0, i0, r6, 0);
	r2 = _JC_INVOKE_VIRTUAL(env, java_util_EventObject, getSource$b11b93305f9d301e, r0);
	r3 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, toString$7ea43b33b80a3070, r2);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r3);
	r4 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r4, r1);
	return r4;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_print_event_PrintEvent$methods[] = {
	&_jc_javax_print_event_PrintEvent$method_info$_init$3fddd28dadb712ab,
	&_jc_javax_print_event_PrintEvent$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_print_event_PrintEvent$instanceof_hash_bucket_43[] = {
	&_jc_java_util_EventObject$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_print_event_PrintEvent$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_print_event_PrintEvent$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_print_event_PrintEvent$instanceof_hash_bucket_115[] = {
	&_jc_javax_print_event_PrintEvent$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_print_event_PrintEvent$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[43]=	_jc_javax_print_event_PrintEvent$instanceof_hash_bucket_43,
	[65]=	_jc_javax_print_event_PrintEvent$instanceof_hash_bucket_65,
	[101]=	_jc_javax_print_event_PrintEvent$instanceof_hash_bucket_101,
	[115]=	_jc_javax_print_event_PrintEvent$instanceof_hash_bucket_115
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_print_event_PrintEvent$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Exception",	_JC_JLONG(0xc5feb325780a6cd7) },
	{ "java/lang/IllegalArgumentException",	_JC_JLONG(0x680cf34d05feb5a1) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/RuntimeException",	_JC_JLONG(0x4f5534a987354d1d) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/VMThrowable",	_JC_JLONG(0xc8d6a6ffc5c1acc1) },
	{ "java/util/EventObject",	_JC_JLONG(0xe4988e4c1a7050ab) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_print_event_PrintEvent$vtype _jc_javax_print_event_PrintEvent$type = {
    .type= {
	.name=			"javax/print/event/PrintEvent",
	.superclass=		&_jc_java_util_EventObject$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0x4c95768fb6372ef3),
		.source_file=		"PrintEvent.java",
		.instance_size=		sizeof(_jc_javax_print_event_PrintEvent$refs) + sizeof(_jc_javax_print_event_PrintEvent$object),
		.num_virtual_refs=	1,
		.num_methods=		sizeof(_jc_javax_print_event_PrintEvent$methods) / sizeof(*_jc_javax_print_event_PrintEvent$methods),
		.methods=		_jc_javax_print_event_PrintEvent$methods,
		.instanceof_hash_table=	_jc_javax_print_event_PrintEvent$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_print_event_PrintEvent$class_depends) / sizeof(*_jc_javax_print_event_PrintEvent$class_depends),
		.class_depends=		_jc_javax_print_event_PrintEvent$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_javax_print_event_PrintEvent$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_util_EventObject= {
	    .getSource$b11b93305f9d301e=
		&_jc_java_util_EventObject$method$getSource$b11b93305f9d301e,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_javax_print_event_PrintEvent$method$toString$7ea43b33b80a3070,
	},
	.javax_print_event_PrintEvent= {
	    .toString$7ea43b33b80a3070=
		&_jc_javax_print_event_PrintEvent$method$toString$7ea43b33b80a3070,
	},
    }
};
